@@ -266,6 +266,12 @@ struct _ts {
 #    define C_RECURSION_LIMIT 3000
 #  elif defined(_Py_ADDRESS_SANITIZER)
 #    define C_RECURSION_LIMIT 4000
+#  elif defined(__sparc__)
+     // test_descr crashed on sparc64 with >7000 but let's keep a margin of error.
+#    define C_RECURSION_LIMIT 4000
+#  elif defined(__hppa__) || defined(__powerpc64__)
+     // test_descr crashed with >8000 but let's keep a margin of error.
+#    define C_RECURSION_LIMIT 5000
 #  else
      // This value is duplicated in Lib/test/support/__init__.py
 #    define C_RECURSION_LIMIT 10000
