@@ -31,20 +31,26 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS_NODIST': '',
  'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
- 'COMPILEALL_OPTS': '-j17',
+ 'COMPILEALL_OPTS': '-j32',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -march=x86-64 -pipe -std=c11 -Wextra '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+                            '-Werror=lto-type-mismatch -Werror=strict-aliasing '
+                            '-flto -flto -fuse-linker-plugin -ffat-lto-objects '
+                            '-g -std=c11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-Wl,--as-needed',
- 'CONFIGURE_LDFLAGS_NOLTO': '',
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
+                             '-Wl,-z,pack-relative-relocs -Werror=odr '
+                             '-Werror=lto-type-mismatch '
+                             '-Werror=strict-aliasing -flto -flto '
+                             '-fuse-linker-plugin -ffat-lto-objects -g',
+ 'CONFIGURE_LDFLAGS_NOLTO': '-fno-lto',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
@@ -62,11 +68,12 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
                 "'--without-assertions' '--disable-optimizations' "
-                "'--with-readline=readline' '--without-valgrind' "
+                "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
-                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
-                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
+                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' "
+                "'PKG_CONFIG_PATH=/usr/share/guile-data/3.0/pkgconfig' "
+                "'CFLAGS=' 'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
@@ -141,10 +148,10 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ATANH': 1,
  'HAVE_BIND': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
- 'HAVE_BROKEN_NICE': 1,
+ 'HAVE_BROKEN_NICE': 0,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -623,15 +630,14 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.12',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.a3u70o_f/bin/ebuild-helpers/xattr/install '
-            '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.a3u70o_f/bin/ebuild-helpers/xattr/install '
-                 '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.a3u70o_f/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
+ 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
+                 '-m 644',
+ 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.a3u70o_f/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.a3u70o_f/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -647,8 +653,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-march=x86-64 -pipe -std=c11 -Wextra '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                    '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
+                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -656,11 +664,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-march=x86-64 -pipe -std=c11 -Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                   '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
+                   '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -g -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
@@ -669,8 +679,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
-                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-march=x86-64 -pipe -std=c11 -Wextra '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                    '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
+                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -983,9 +995,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__TESTINTERNALCAPI_STATE': 'yes',
  'MODULE__TESTMULTIPHASE_STATE': 'yes',
  'MODULE__THREAD_LDFLAGS': '',
- 'MODULE__TKINTER_CFLAGS': '-Wno-strict-prototypes -DWITH_APPINIT=1',
- 'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
- 'MODULE__TKINTER_STATE': 'yes',
+ 'MODULE__TKINTER_STATE': 'missing',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
  'MODULE__TYPING_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
@@ -1038,8 +1048,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                             '-march=x86-64 -pipe -std=c11 -Wextra '
-                             '-Wno-unused-parameter '
+                             '-pipe -march=x86-64-v3 -Werror=odr '
+                             '-Werror=lto-type-mismatch '
+                             '-Werror=strict-aliasing -flto -flto '
+                             '-fuse-linker-plugin -ffat-lto-objects -g '
+                             '-std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
@@ -1047,33 +1060,45 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -march=x86-64 -pipe -std=c11 -Wextra '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes '
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+                     '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                     '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                     '-Wextra -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-march=x86-64 -pipe -std=c11 -Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                   '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
+                   '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                   '-ffat-lto-objects -g -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,--as-needed',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                    '-Werror=odr -Werror=lto-type-mismatch '
+                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,--as-needed',
- 'PY_LDFLAGS_NOLTO': '',
+ 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                      '-Werror=odr -Werror=lto-type-mismatch '
+                      '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                      '-ffat-lto-objects -g',
+ 'PY_LDFLAGS_NOLTO': '-fno-lto',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-march=x86-64 -pipe -std=c11 -Wextra '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
+                        '-pipe -march=x86-64-v3 -Werror=odr '
+                        '-Werror=lto-type-mismatch -Werror=strict-aliasing '
+                        '-flto -flto -fuse-linker-plugin -ffat-lto-objects -g '
+                        '-std=c11 -Wextra -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
